@@ -385,7 +385,7 @@ class Mysql:
         cursor = self._conn.cursor()
         try:
             cursor.execute(sql, args)
-            return self.lastrowid
+            return cursor.lastrowid
         finally:
             cursor.close()
 
@@ -465,7 +465,7 @@ class AioMysql(Mysql):
         cursor = await self._conn.cursor()
         try:
             await cursor.execute(sql, args)
-            return self._lastrowid
+            return cursor._lastrowid
         finally:
             await cursor.close()
 
