@@ -37,7 +37,13 @@ def Fire(component=None):
         func = getattr(component, sys.argv[1])
         params = sys.argv[2:]
 
-    ret = func(*params)
+    args = []
+    for v in params:
+        if v.startswith('--'):
+            break
+        else:
+            args.append(v)
+    ret = func(*args)
     if inspect.isawaitable(ret):
         loop = asyncio.get_event_loop()
         ret = loop.run_until_complete(ret)
